@@ -1,5 +1,4 @@
-Brook <-
-function(x,thr,ths,alp,nscal){
+Brook = function(x,thr,ths,alp,nscal){
 .value<-thr+(ths-thr)/(alp*x)^nscal
 .value
 }
